==> json-joy-2.5.3.tgz: package/esm/json-rx/JsonRxClient.js <==
import { Observable } from 'rxjs';
import { assertId, isArray } from './util';
import { TimedQueue } from './TimedQueue';
export class JsonRxClient {
    constructor({ send, bufferSize = 100, bufferTime = 10 }) {
        this.cnt = 1;
        this.observers = new Map();
        this.buffer = new TimedQueue();
        this.buffer.itemLimit = bufferSize;
        this.buffer.timeLimit = bufferTime;
        this.buffer.onFlush = (messages) => {
            send(messages.length === 1 ? messages[0] : messages);
        };
    }
    sendSubscribe(message) {
        this.buffer.push(message);
    }
    sendUnsubscribe(id) {
        this.buffer.push([-3, id]);
    }
    onData(message) {
        const [, id, payload] = message;
        assertId(id);
        const observer = this.observers.get(id);
        if (!observer)
            return;
        observer.observer.next(payload);
    }
    onComplete(message) {
        const [, id, payload] = message;
        assertId(id);
        const observer = this.observers.get(id);
        if (!observer)
            return;
        observer.completed = true;
        if (payload !== undefined)
            observer.observer.next(payload);
        observer.observer.complete();
    }
    onError(message) {
        const [, id, error] = message;
        assertId(id);
        const observer = this.observers.get(id);
        if (!observer)
            return;
        observer.completed = true;
        observer.observer.error(error);
    }
    onMessage(message) {
        if (!isArray(message))
            throw new Error('Invalid message');
        const [type] = message;
        if (isArray(type)) {
            for (let i = 0; i < message.length; i++)
                this.onMessage(message[i]);
            return;
        }
        if (type === 0)
            return this.onComplete(message);
        if (type === -1)
            return this.onError(message);
        if (type === -2)
            return this.onData(message);
        throw new Error('Invalid message');
    }
    call(method, payload) {
        const id = this.cnt++;
        const observable = new Observable((observer) => {
            const entry = { observer };
            this.observers.set(id, entry);
            return () => {
                this.observers.delete(id);
                if (!entry.completed)
                    this.sendUnsubscribe(id);
            };
        });
        this.sendSubscribe([id, method, payload]);
        return observable;
    }
    notify(name, payload) {
        const message = payload !== undefined ? [name, payload] : [name];
        this.buffer.push(message);
    }
    stop() {
        this.buffer.onFlush = (message) => { };
        for (const { observer } of this.observers.values())
            observer.complete();
    }
}

==> json-joy-7.11.0.tgz: package/esm/json-rx/JsonRxClient.js <==
import { Observable } from 'rxjs';
import { assertId, isArray } from './util';
import { TimedQueue } from './TimedQueue';
export class JsonRxClient {
    cnt = 1;
    buffer;
    observers = new Map();
    constructor({ send, bufferSize = 100, bufferTime = 10 }) {
        this.buffer = new TimedQueue();
        this.buffer.itemLimit = bufferSize;
        this.buffer.timeLimit = bufferTime;
        this.buffer.onFlush = (messages) => {
            send(messages.length === 1 ? messages[0] : messages);
        };
    }
    sendSubscribe(message) {
        this.buffer.push(message);
    }
    sendUnsubscribe(id) {
        this.buffer.push([-3, id]);
    }
    onData(message) {
        const [, id, payload] = message;
        assertId(id);
        const observer = this.observers.get(id);
        if (!observer)
            return;
        observer.observer.next(payload);
    }
    onComplete(message) {
        const [, id, payload] = message;
        assertId(id);
        const observer = this.observers.get(id);
        if (!observer)
            return;
        observer.completed = true;
        if (payload !== undefined)
            observer.observer.next(payload);
        observer.observer.complete();
    }
    onError(message) {
        const [, id, error] = message;
        assertId(id);
        const observer = this.observers.get(id);
        if (!observer)
            return;
        observer.completed = true;
        observer.observer.error(error);
    }
    onMessage(message) {
        if (!isArray(message))
            throw new Error('Invalid message');
        const [type] = message;
        if (isArray(type)) {
            for (let i = 0; i < message.length; i++)
                this.onMessage(message[i]);
            return;
        }
        if (type === 0)
            return this.onComplete(message);
        if (type === -1)
            return this.onError(message);
        if (type === -2)
            return this.onData(message);
        throw new Error('Invalid message');
    }
    call(method, payload) {
        const id = this.cnt++;
        const observable = new Observable((observer) => {
            const entry = { observer };
            this.observers.set(id, entry);
            return () => {
                this.observers.delete(id);
                if (!entry.completed)
                    this.sendUnsubscribe(id);
            };
        });
        this.sendSubscribe([id, method, payload]);
        return observable;
    }
    notify(name, payload) {
        const message = payload !== undefined ? [name, payload] : [name];
        this.buffer.push(message);
    }
    stop() {
        this.buffer.onFlush = (message) => { };
        for (const { observer } of this.observers.values())
            observer.complete();
    }
}
